Font-awesome SCSS ready to be used with cradmin themes.


## How to update font-awesome
To update font-awesome, you need to download the font-awesome source distribution from 
https://fontawesome.com/.

In this directory:

- Remove the `scss` directory.
- Copy the `web-fonts-with-css/scss` directory from the fontawesome source distribution
  into this directory.
  
In the `django_cradmin/apps/django_cradmin_styles/staticsources/django_cradmin_styles/media/cradmin_fontawesome/`
directory:

- Remove the `webfonts` directory.
- Copy the `web-fonts-with-css/webfonts` directory from the fontawesome source distribution
  into the directory.
